Title: [227871] trunk/Tools
Revision
227871
Author
[email protected]
Date
2018-01-30 20:27:41 -0800 (Tue, 30 Jan 2018)

Log Message

[webkitpy] Config file for apache is copied twice.
https://bugs.webkit.org/show_bug.cgi?id=182131

Patch by Basuke Suzuki <[email protected]> on 2018-01-30
Reviewed by Daniel Bates.

* Scripts/webkitpy/layout_tests/servers/apache_http_server.py:
(LayoutTestApacheHttpd.__init__):
(LayoutTestApacheHttpd._copy_apache_config_file):
(LayoutTestApacheHttpd._get_apache_config_file_path): Deleted.

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (227870 => 227871)


--- trunk/Tools/ChangeLog	2018-01-31 04:23:50 UTC (rev 227870)
+++ trunk/Tools/ChangeLog	2018-01-31 04:27:41 UTC (rev 227871)
@@ -1,3 +1,15 @@
+2018-01-30  Basuke Suzuki  <[email protected]>
+
+        [webkitpy] Config file for apache is copied twice.
+        https://bugs.webkit.org/show_bug.cgi?id=182131
+
+        Reviewed by Daniel Bates.
+
+        * Scripts/webkitpy/layout_tests/servers/apache_http_server.py:
+        (LayoutTestApacheHttpd.__init__):
+        (LayoutTestApacheHttpd._copy_apache_config_file):
+        (LayoutTestApacheHttpd._get_apache_config_file_path): Deleted.
+
 2018-01-30  Don Olmstead  <[email protected]>
 
         JSExports.h should be included as <_javascript_Core/JSExportMacros.h>

Modified: trunk/Tools/Scripts/webkitpy/layout_tests/servers/apache_http_server.py (227870 => 227871)


--- trunk/Tools/Scripts/webkitpy/layout_tests/servers/apache_http_server.py	2018-01-31 04:23:50 UTC (rev 227870)
+++ trunk/Tools/Scripts/webkitpy/layout_tests/servers/apache_http_server.py	2018-01-31 04:27:41 UTC (rev 227871)
@@ -89,9 +89,10 @@
 
         # FIXME: We shouldn't be calling a protected method of _port_obj!
         executable = self._port_obj._path_to_apache()
+        config_file_path = self._copy_apache_config_file(self.tests_dir, output_dir)
 
         start_cmd = [executable,
-            '-f', "\"%s\"" % self._get_apache_config_file_path(self.tests_dir, output_dir),
+            '-f', "\"%s\"" % config_file_path,
             '-C', "\'DocumentRoot \"%s\"\'" % document_root,
             '-c', "\'TypesConfig \"%s\"\'" % mime_types_path,
             '-c', "\'PHPINIDir \"%s\"\'" % php_ini_dir,
@@ -141,7 +142,7 @@
                         '-c', "\'</Location>\'"]
 
         stop_cmd = [executable,
-            '-f', "\"%s\"" % self._get_apache_config_file_path(self.tests_dir, output_dir),
+            '-f', "\"%s\"" % config_file_path,
             '-c', "\'PidFile %s'" % self._pid_file,
             '-k', "stop"]
 
@@ -153,8 +154,8 @@
         self._start_cmd = " ".join(start_cmd)
         self._stop_cmd = " ".join(stop_cmd)
 
-    def _get_apache_config_file_path(self, test_dir, output_dir):
-        """Returns the path to the apache config file to use.
+    def _copy_apache_config_file(self, test_dir, output_dir):
+        """Copy apache config file and returns the path to use.
         Args:
           test_dir: absolute path to the LayoutTests directory.
           output_dir: absolute path to the layout test results directory.
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to